# omni-ply

> Before your code complexity multiplies, use omniply.

Tools and structures for stellar research code without compromises.

This project is currently under development - lots of cool things coming soon.
